Update tintin++ to 2.01.0, from Ted Roby <troby AT freeshell DOT org>

(taking MAINTAINER)
ok landry@
This commit is contained in:
bcallah 2014-01-04 07:51:53 +00:00
parent 06ad0f0baa
commit ad0aa07965
13 changed files with 25 additions and 383 deletions

View File

@ -1,29 +1,34 @@
# $OpenBSD: Makefile,v 1.18 2013/12/10 23:42:29 jca Exp $
# $OpenBSD: Makefile,v 1.19 2014/01/04 07:51:53 bcallah Exp $
COMMENT= client program to help playing muds
DISTNAME= tintin++v1.5pl6
PKGNAME= tintin-1.5.6
REVISION= 1
COMMENT= client program for playing muds with advanced features
DISTNAME= tintin-2.01.0
CATEGORIES= net games
MASTER_SITES= http://ftp.kiae.su/pub/unix/games/
EXTRACT_SUFX= .tar.Z
HOMEPAGE= http://tintin.sourceforge.net/
MAINTAINER= Ted Roby <troby@freeshell.org>
# Public Domain
# GPLv2+
PERMIT_PACKAGE_CDROM= Yes
WANTLIB += c
WANTLIB += c pcre pthread util z
CONFIGURE_STYLE= gnu old
MASTER_SITES= ${MASTER_SITE_SOURCEFORGE:=tintin/}
WRKDIST= ${WRKDIR}/tintin++/src
LIB_DEPENDS= devel/pcre
CONFIGURE_STYLE= gnu
CONFIGURE_ENV= CPPFLAGS="-I${LOCALBASE}/include" \
LDFLAGS="-L${LOCALBASE}/lib"
MAKE_FLAGS= INCS=-I${LOCALBASE}/include
WRKDIST= ${WRKDIR}/tt/src
NO_TEST= Yes
do-install:
${INSTALL_DATA_DIR} ${PREFIX}/lib/tintin
${INSTALL_DATA_DIR} ${PREFIX}/share/doc/tintin++
${INSTALL_DATA} ${WRKDIR}/tt/docs/chat_protocol.txt ${PREFIX}/share/doc/tintin++
${INSTALL_DATA} ${WRKDIR}/tt/docs/tintin19.txt ${PREFIX}/share/doc/tintin++
${INSTALL_PROGRAM} ${WRKSRC}/tt++ ${PREFIX}/bin
${INSTALL_DATA} ${WRKSRC}/support/.tt_help.txt.Z ${PREFIX}/lib/tintin
.include <bsd.port.mk>

View File

@ -1,5 +1,2 @@
MD5 (tintin++v1.5pl6.tar.Z) = NeU9ZhYG0DXD6SoknkQWDw==
RMD160 (tintin++v1.5pl6.tar.Z) = iyDVrnwyTOt4Gj5eXeWKvld/Cks=
SHA1 (tintin++v1.5pl6.tar.Z) = aybfgVFdRTk6aMoOW9FxKHu3ezQ=
SHA256 (tintin++v1.5pl6.tar.Z) = mpU9NhEUm+g0/IEmXjwTJNhdy9r8ZsbvuEDa+o8zSi8=
SIZE (tintin++v1.5pl6.tar.Z) = 176477
SHA256 (tintin-2.01.0.tar.gz) = 4ONUY6l+5bM+8LKbLFf6gnbE52MoyxnJim6pLGA6nHY=
SIZE (tintin-2.01.0.tar.gz) = 293651

View File

@ -1,45 +0,0 @@
$OpenBSD: patch-Makefile_in,v 1.1 2007/10/26 22:10:06 ajacoutot Exp $
--- Makefile.in.orig Fri Sep 9 17:35:20 1994
+++ Makefile.in Sat Oct 27 00:05:07 2007
@@ -10,8 +10,7 @@
# try uncommenting the 'gcc' line and commenting the 'cc' one.
# Tintin++ doesn't *need* an ANSI compiler anymore, but gcc
# is still better than cc on many platforms...
-CC = @CC@ -O
-CFLAGS = @DEFS@
+CFLAGS += @DEFS@
LIBS = @LIBS@
PIPE = @PIPE@
# If you plan on doing debugging (with gdb), it is very helpful to turn all
@@ -22,10 +21,10 @@ PIPE = @PIPE@
# BINDIR is the directory you wish tt++ to be placed if you wish to use
# make install.
-BINDIR = ..
+BINDIR = /usr/local/bin
# DEFAULT_FILE_DIR is the path to tintin files.
-DEFAULT_FILE_DIR = @HOME@
+DEFAULT_FILE_DIR = /usr/local/lib/tintin
#########################################
# You shouldn't need to change anything #
@@ -41,14 +40,15 @@ CFILES = main.c parse.c action.c alias.c substitute.c
variables.c highlight.c antisub.c ivars.c help.c text.c glob.c
OFILES = $(CFILES:.c=.o)
-all: tintin++ install
+all: tintin++
tintin++: $(OFILES) tintin.h
@echo "Linking..."
$(CC) $(CFLAGS) $(FFLAGS) $(LFLAGS) -o tt++ $(OFILES) $(LIBS)
-install: all
- @./install.sh $(BINDIR) $(DEFAULT_FILE_DIR) $(COMPRESSED_HELP)
+install:
+ @mkdir -p $(DEFAULT_FILE_DIR)
+ @./install.sh $(BINDIR) $(DEFAULT_FILE_DIR) Ok
# Autocompile all .c files into .o files using this rule:
.c.o:

View File

@ -1,69 +0,0 @@
$OpenBSD: patch-configure,v 1.2 2013/12/07 22:37:14 jca Exp $
--- configure.orig Sun Aug 28 12:06:38 1994
+++ configure Fri Dec 6 15:14:46 2013
@@ -474,17 +474,20 @@ fi
OLD_CFLAGS="$CFLAGS"
CFLAGS="$CFLAGS -pipe"
-echo "Do you want the helpfile to be compressed (yes/no)? "
-read YESNO
-if test $YESNO; then
- if echo "$YESNO"|grep -i "no" >/dev/null; then
- DEFS="$DEFS -DCOMPRESSED_HELP=0"
- else
- DEFS="$DEFS -DCOMPRESSED_HELP=1"
- COMPRESSED_HELP="Ok"
- fi
-fi
+DEFS="$DEFS -DCOMPRESSED_HELP=1"
+COMPRESSED_HELP="Ok"
+#echo "Do you want the helpfile to be compressed (yes/no)? "
+#read YESNO
+#if test $YESNO; then
+# if echo "$YESNO"|grep -i "no" >/dev/null; then
+# DEFS="$DEFS -DCOMPRESSED_HELP=0"
+# else
+# DEFS="$DEFS -DCOMPRESSED_HELP=1"
+# COMPRESSED_HELP="Ok"
+# fi
+#fi
+
test -n "$silent" || echo "checking for -pipe"
cat > conftest.${ac_ext} <<EOF
#include "confdefs.h"
@@ -754,7 +757,7 @@ else
fi
-for ac_hdr in strings.h string.h stdlib.h time.h sys/termio.h
+for ac_hdr in strings.h string.h stdlib.h time.h sys/termio.h termios.h
do
ac_tr_hdr=HAVE_`echo $ac_hdr | tr '[a-z]./' '[A-Z]__'`
test -n "$silent" || echo "checking for ${ac_hdr}"
@@ -790,6 +793,16 @@ if egrep "tcflag_t" conftest.out >/dev/null 2>&1; then
fi
rm -f conftest*
+echo '#include "confdefs.h"
+#include <termios.h>' > conftest.${ac_ext}
+eval "$ac_cpp conftest.${ac_ext} > conftest.out 2>&1"
+if egrep "tcflag_t" conftest.out >/dev/null 2>&1; then
+ rm -rf conftest*
+ DEFS="$DEFS -DHAVE_TCFLAG_T=1"
+
+fi
+rm -f conftest*
+
test -n "$silent" || echo "checking for which method to use to turn keyboard echo on/off"
cat > conftest.${ac_ext} <<EOF
#include "confdefs.h"
@@ -854,7 +867,7 @@ else
:;
fi
-for ac_func in bcopy
+for ac_func in
do
ac_tr_func=HAVE_`echo $ac_func | tr '[a-z]' '[A-Z]'`
test -n "$silent" || echo "checking for ${ac_func}"

View File

@ -1,94 +0,0 @@
$OpenBSD: patch-echo_c,v 1.1 2013/12/07 22:37:14 jca Exp $
--- echo.c.orig Sun Aug 28 16:11:56 1994
+++ echo.c Fri Dec 6 17:04:16 2013
@@ -18,19 +18,27 @@
#include <sys/ioctl.h>
#endif
+#if defined(HAVE_TERMIOS_H)
+#include <termios.h>
+#else
#if defined(HAVE_SYS_TERMIO_H) && !defined(BSD_ECHO)
#include <sys/termio.h>
+#define termios termio
+#define tcgetattr(a, b) ioctl((a), TCGETA, (b))
+#define tcsetattr(a, XXX, b) ioctl((a), TCSETA, (b))
#else
#include <sgtty.h>
#if DIRTY_REDEFINE
+/* ... */
#undef TIOCGETP
#undef TIOCSETP
#define TIOCGETP 0x40067408
#define TIOCSETP 0x80067409
#endif
#endif
+#endif
-#if defined(HAVE_SYS_TERMIO_H) && !defined(BSD_ECHO)
+#if defined(HAVE_TERMIOS_H) || (defined(HAVE_SYS_TERMIO_H) && !defined(BSD_ECHO))
#ifdef HAVE_TCFLAG_T
extern tcflag_t c_lflag;
extern cc_t c_cc[NCCS];
@@ -41,46 +49,46 @@ extern unsigned char c_cc[NCC];
void init_echo()
{
- struct termio io;
+ struct termios io;
- if(ioctl(0, TCGETA, &io)<0)
- syserr("ioctl");
+ if(tcgetattr(0, &io)<0)
+ syserr("tcgetattr/ioctl");
c_lflag = io.c_lflag;
c_cc[VMIN] = io.c_cc[VMIN];
c_cc[VTIME] = io.c_cc[VTIME];
}
/********************************/
-/* turn echo on - HP-UX version */
+/* turn echo on - POSIX version */
/********************************/
void term_echo()
{
- struct termio io;
+ struct termios io;
- if(ioctl(0, TCGETA, &io)<0)
- syserr("ioctl");
+ if(tcgetattr(0, &io)<0)
+ syserr("tcgetattr/ioctl");
io.c_lflag = c_lflag;
io.c_cc[VMIN] = c_cc[VMIN];
io.c_cc[VTIME] = c_cc[VTIME];
- if(ioctl(0, TCSETA, &io)<0)
- syserr("ioctl");
+ if(tcsetattr(0, TCSANOW, &io)<0)
+ syserr("tcsetattr/ioctl");
}
/*********************************/
-/* turn echo off - HP-UX version */
+/* turn echo off - POSIX version */
/*********************************/
void term_noecho()
{
- struct termio io;
+ struct termios io;
- if(ioctl(0, TCGETA, &io)<0)
- syserr("ioctl");
+ if(tcgetattr(0, &io)<0)
+ syserr("tcgetattr/ioctl");
io.c_lflag &= ~ECHO;
io.c_lflag &= ~ICANON;
io.c_cc[VMIN]=1;
io.c_cc[VTIME]=0;
- if(ioctl(0, TCSETA, &io) < 0)
- syserr("ioctl");
+ if(tcsetattr(0, TCSANOW, &io) < 0)
+ syserr("tcsetattr/ioctl");
}
#else /* BSD-ISH machine */

View File

@ -1,11 +0,0 @@
$OpenBSD: patch-files_c,v 1.1 2010/01/11 07:19:17 ajacoutot Exp $
--- files.c.orig Mon Jan 11 03:22:56 2010
+++ files.c Mon Jan 11 03:23:09 2010
@@ -13,6 +13,7 @@
#include <strings.h>
#endif
#endif
+#include <stdlib.h>
#include "tintin.h"
struct listnode *common_aliases, *common_actions, *common_subs,

View File

@ -1,18 +0,0 @@
$OpenBSD: patch-install_sh,v 1.1 2007/10/26 22:10:06 ajacoutot Exp $
--- install.sh.orig Fri Sep 9 03:43:26 1994
+++ install.sh Sat Oct 27 00:05:07 2007
@@ -5,12 +5,11 @@
echo " "
echo "Copying the tintin++ executable to \"$1\"..."
-strip tt++
-cp tt++ "$1"
+install -c -s -o bin -g bin -m 555 tt++ "$1"
echo "Copying the tintin++ help file to \"$2\"..."
if [ "$3" ]; then
- cp support/.tt_help.txt.Z "$2/"
+ install -c -o bin -g bin -m 444 support/.tt_help.txt.Z "$2"
else
echo Uncompressing.
uncompress -c support/.tt_help.txt.Z | cat > "$2"/.tt_help.txt

View File

@ -1,53 +0,0 @@
$OpenBSD: patch-main_c,v 1.2 2013/12/07 22:37:14 jca Exp $
--- main.c.orig Sun Aug 28 16:12:06 1994
+++ main.c Fri Dec 6 15:10:34 2013
@@ -100,8 +100,12 @@ int write();
extern void term_echo();
int last_line_length;
-#if defined(HAVE_SYS_TERMIO_H) && !defined(BSD_ECHO)
+#if defined(HAVE_TERMIOS_H) || (defined(HAVE_SYS_TERMIO_H) && !defined(BSD_ECHO))
+#ifdef HAVE_TERMIOS_H
+#include <termios.h>
+#else
#include <sys/termio.h>
+#endif
#ifdef HAVE_TCFLAG_T
tcflag_t c_lflag;
cc_t c_cc[NCCS];
@@ -562,7 +566,7 @@ void read_mud(ses)
if(ses->logfile) {
if (!OLD_LOG) {
count=0;
- for(n=0;n<=didget;n++)
+ for(n=0;n<didget;n++)
if (buffer[n]!='\r') {
temp[count]=buffer[n];
count++;
@@ -732,7 +736,7 @@ void tintin_puts2(cptr, ses)
sprintf(strng,"%c8%s\n\r%c7%c[%d;%df", E, cptr, E, E, input_row, input_col);
else
sprintf(strng,"%s\n\r", cptr);
- write(1,strng, strlen(strng)+1);
+ write(1,strng, strlen(strng));
display_col=1;
if (redraw && term_echoing && !is_split)
write(1, k_input, strlen(k_input));
@@ -764,7 +768,7 @@ void tintin_puts3(cptr, ses)
cptr++;
sprintf(strng,"%s\n\r", cptr);
}
- write(1,strng, strlen(strng)+1);
+ write(1,strng, strlen(strng));
display_col=1;
}
text_came=TRUE;
@@ -832,7 +836,7 @@ void split_command(arg)
input_col=1;
sprintf(fn, "%c[2J%c[1;%dr%c[%d;1f", E, E, display_row, E, split_line);
write(1,fn, strlen(fn));
- write(1,"-------------------------------------------------------------------------------", 80);
+ write(1,"--------------------------------------------------------------------------------", 80);
sprintf(fn, "%c[%d;1f%c7", E, split_line-1, E);
write(1,fn,strlen(fn));
sprintf(fn, "%c[%d;1f", E, input_row);

View File

@ -1,21 +0,0 @@
$OpenBSD: patch-misc_c,v 1.2 2010/01/11 07:19:17 ajacoutot Exp $
--- misc.c.orig Sun Aug 28 16:12:08 1994
+++ misc.c Mon Jan 11 08:15:04 2010
@@ -106,7 +106,7 @@ void bell_command(ses)
char temp[2];
temp[0]=7;
temp[1]=0;
- write(1, temp, 2);
+ write(1, temp, 1);
}
@@ -172,7 +172,7 @@ void end_command(command, ses)
cleanup_session(sesptr);
ses=NULL;
if (is_split)
- write(1, "c", 3);
+ write(1, "c", 2);
tintin_puts2("TINTIN suffers from bloodlack, and the lack of a beating heart...", ses);
tintin_puts2("TINTIN is dead! R.I.P.", ses);
tintin_puts2("Your blood freezes as you hear TINTIN's death cry.", ses);

View File

@ -1,12 +0,0 @@
$OpenBSD: patch-net_c,v 1.1 2007/10/26 22:10:06 ajacoutot Exp $
--- parse.c.orig Sun Aug 28 16:12:10 1994
+++ parse.c Mon Jan 11 08:15:04 2010
@@ -670,10 +670,10 @@ void prompt(ses)
if(ses && !PSEUDO_PROMPT)
write_line_mud("", ses);
else if (!is_split)
- write(1,"> ", 3);
+ write(1,"> ", 2);
else {
sprintf(strng,"8> 7[%d;%df", input_row, input_col);
- write(1,strng, strlen(strng)+1);
+ write(1,strng, strlen(strng));
display_col+=2;
}
}

View File

@ -1,22 +0,0 @@
$OpenBSD: patch-utils_c,v 1.1 2007/10/26 22:10:06 ajacoutot Exp $
--- utils.c.orig Sun Aug 28 16:12:16 1994
+++ utils.c Sat Oct 27 00:05:07 2007
@@ -21,6 +21,8 @@
#include <unistd.h>
#endif
+#include <sys/param.h>
+
void syserr();
/*********************************************/
@@ -56,7 +58,9 @@ void syserr(msg)
char *msg;
{
extern int errno, sys_nerr;
+#if !defined(BSD) || (BSD < 199306)
extern char *sys_errlist[];
+#endif
fprintf(stderr,"ERROR: %s (%d",msg, errno);
if(errno>0 && errno<sys_nerr)

View File

@ -1,4 +1,5 @@
@comment $OpenBSD: PLIST,v 1.5 2010/01/11 07:19:17 ajacoutot Exp $
@comment $OpenBSD: PLIST,v 1.6 2014/01/04 07:51:53 bcallah Exp $
@bin bin/tt++
lib/tintin/
lib/tintin/.tt_help.txt.Z
share/doc/tintin++/
share/doc/tintin++/chat_protocol.txt
share/doc/tintin++/tintin19.txt
--- net.c.orig Sun Aug 28 16:12:10 1994
+++ net.c Sat Oct 27 00:05:07 2007
@@ -80,7 +80,7 @@ int connect_mud(host, port, ses)
tintin_puts("#Trying to connect..", ses);
- alarm(15); /* We'll allow connect to hang in 15seconds! NO MORE! */
+ alarm(30); /* We'll allow connect to hang in 30seconds! NO MORE! */
ticker_interrupted=FALSE;
connectresult=connect(sock, (struct sockaddr *)&sockaddr, sizeof(sockaddr));
#if defined(DEBUG)

View File

@ -1,16 +0,0 @@
$OpenBSD: patch-parse_c,v 1.2 2010/01/11 07:19:17 ajacoutot Exp $